@@ -352,7 +352,7 @@ class XYProjGridder(XYGridderBase):
         }
 
 
-class LonLatSurroundingGrid(XYGridderBase):
+class LonLatSurroundingGridder(XYGridderBase):
     def __init__(self, lon0, lat0, rmin, rmax, nr, ntheta, theta0=0.0, r_earth=6371):
         self.lon0 = lon0
         self.lat0 = lat0
@@ -396,6 +396,14 @@ class LonLatSurroundingGrid(XYGridderBase):
         lat = np.rad2deg(lat_)
         return lon, lat
 
+    @property
+    def nx(self):
+        return self.ntheta
+
+    @property
+    def ny(self):
+        return self.nr
+
     @property
     def X(self):
         return self._X
